cli_components library
Library for simple, self-contained interactive CLI components.
Functions
-
showMultiSelectDialog(
List< String> options, Stream<List< inputStream, {int maxVisibleItems = 5, Set<int> >int> initialSelected = const {}}) → Future<Set< int> ?> - Shows a scrollable terminal selection dialog and returns the set of selected indices.
-
showSingleSelectDialog(
List< String> options, Stream<List< inputStream, {int maxVisibleItems = 5}) → Future<int> >int?> - Shows a scrollable terminal selection dialog and returns the selected index.